==> yawp-0.2.tar.bz2: yawp-0.2/yawpconfig.h <==
//
// C++ Implementation: yawp
//
// Description:
//
//
// Author: Ruan <ruans@kr8.co.za>, (C) 2008
//
// Copyright: Do what you want, whenever you want.
//
//
#ifndef YAWP_CONFIG_H
#define YAWP_CONFIG_H

#include <QWidget>
#include <QDialog>
#include <kio/job.h>
#include <QMap>

#include "ui_yawpunitspage.h"
#include "ui_yawpthemepage.h"
#include "ui_yawplocationpage.h"

#define YAWP_VERSION "0.1.0"

class KProgressDialog;
class KConfigDialog;

//-----------------------------------------------------------------------------
/** Configuration window.
	@author Ruan <ruans@kr8.co.za>
 */
class YaWPConfigDialog : public QObject, public Ui::UnitsPage,
  public Ui::ThemePage, public Ui::LocationPage {
    Q_OBJECT
public:
    YaWPConfigDialog(KConfigDialog*);
    virtual ~YaWPConfigDialog();

    void setInterval(int inter);
    int interval() const;

    void setTheme(const QString &theme);
    QString theme() const;

    void setCity(const QString &city);
    QString city() const;

    void setCountry(const QString &country);
    QString country() const;

    void setLocation(const QString &code);
    QString location();

    void setUnits(int units);
    int units() const;

    void setService(const QString &service);
    QString service() const;

    void setUseCustomTheme(bool enabled);
    bool useCustomTheme() const;
    
    void setCustomTheme(const QString &file);
    QString customTheme() const;
    
    void setUseCustomThemeBackground(bool enabled);
    bool useCustomThemeBackground() const;

    void setPanelActualTemp(bool enabled);
    bool panelActualTemp() const;

    void setPanelActualIcon(bool enabled);
    bool panelActualIcon() const;

    void setPanelActualBoth(bool enabled);
    bool panelActualBoth() const;

    void setPanelForecastTemp(bool enabled);
    bool panelForecastTemp() const;

    void setPanelForecastIcon(bool enabled);
    bool panelForecastIcon() const;

    void setPanelForecastBoth(bool enabled);
    bool panelForecastBoth() const;

    void setPanelForecastDays(int days);
    int panelForecastDays() const;
    
signals:
    void save();

protected slots:
    //void serviceChanged(const QString & text);
    void fileSelected(int state);
    void showFileDialog();
    void showAccuweatherPage();

    void itemClicked(QListWidgetItem *item);
    void find();
    void slotData( KIO::Job *, const QByteArray & );
    void slotResult(KJob *);
private:

    void setCustomThemeEnabled(bool value);
    
    QString        m_location;
    QString        m_city;
    QString        m_country;
    QMap <int, QString>   m_theme_map;
    KConfigDialog  *m_parent;

    bool parseInfo(const QByteArray &data);
    QByteArray          m_xmldata;
    KProgressDialog     *m_diag;

    enum {COUNTRY_DATA = Qt::UserRole + 2, CITY_DATA = Qt::UserRole + 1, LOCATION_DATA = Qt::UserRole};
};

#endif //YAWP_CONFIG_H

==> yawp-0.2.1.tar.bz2: yawp-0.2.1/yawpconfig.h <==
//
// C++ Implementation: yawp
//
// Description:
//
//
// Author: Ruan <ruans@kr8.co.za>, (C) 2008
//
// Copyright: Do what you want, whenever you want.
//
//
#ifndef YAWP_CONFIG_H
#define YAWP_CONFIG_H

#include <QWidget>
#include <QDialog>
#include <kio/job.h>
#include <QMap>
#include <QColor>

#include "ui_yawpunitspage.h"
#include "ui_yawpthemepage.h"
#include "ui_yawplocationpage.h"
#include "ui_yawppanelpage.h"

#define YAWP_VERSION "0.1.0"

class KProgressDialog;
class KConfigDialog;

//-----------------------------------------------------------------------------
/** Configuration window.
	@author Ruan <ruans@kr8.co.za>
 */
class YaWPConfigDialog : public QObject, public Ui::UnitsPage,
  public Ui::ThemePage, public Ui::LocationPage, public Ui::PanelPage {
    Q_OBJECT
public:
    YaWPConfigDialog(KConfigDialog*);
    virtual ~YaWPConfigDialog();

    void setInterval(int inter);
    int interval() const;

    void setTheme(const QString &theme);
    QString theme() const;

    void setCity(const QString &city);
    QString city() const;

    void setCountry(const QString &country);
    QString country() const;

    void setLocation(const QString &code);
    QString location();

    void setUnits(int units);
    int units() const;

    void setService(const QString &service);
    QString service() const;

    void setUseCustomTheme(bool enabled);
    bool useCustomTheme() const;

    void setCustomTheme(const QString &file);
    QString customTheme() const;

    void setUseCustomThemeBackground(bool enabled);
    bool useCustomThemeBackground() const;

    void setPanelActualTemp(bool enabled);
    bool panelActualTemp() const;

    void setPanelActualIcon(bool enabled);
    bool panelActualIcon() const;

    void setPanelActualBoth(bool enabled);
    bool panelActualBoth() const;

    void setPanelForecastTemp(bool enabled);
    bool panelForecastTemp() const;

    void setPanelForecastIcon(bool enabled);
    bool panelForecastIcon() const;

    void setPanelForecastBoth(bool enabled);
    bool panelForecastBoth() const;

    void setPanelForecastDays(int days);
    int panelForecastDays() const;

    void setUseCustomColor(bool enabled);
    bool useCustomColor() const;

    void setFontColor(QColor color);
    QColor fontColor() const;

    void setFontLowerColor(QColor color);
    QColor fontLowerColor() const;

signals:
    void save();

protected slots:
    //void serviceChanged(const QString & text);
    void fileSelected(int state);
    void showFileDialog();
    void showAccuweatherPage();

    void itemClicked(QListWidgetItem *item);
    void find();
    void slotData( KIO::Job *, const QByteArray & );
    void slotResult(KJob *);

    void customColorSelected(int state);

private:

    void setCustomThemeEnabled(bool value);
    void setCustomColorsEnabled(bool value);

    QString        m_location;
    QString        m_city;
    QString        m_country;
    QMap <int, QString>   m_theme_map;
    KConfigDialog  *m_parent;

    bool parseInfo(const QByteArray &data);
    QByteArray          m_xmldata;
    KProgressDialog     *m_diag;

    enum {COUNTRY_DATA = Qt::UserRole + 2, CITY_DATA = Qt::UserRole + 1, LOCATION_DATA = Qt::UserRole};
};

#endif //YAWP_CONFIG_H
